Crate solana_transaction_metrics_tracker

Crate solana_transaction_metrics_tracker 

👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.

Functions

get_signature_from_packetDeprecated
Get the signature of the transaction packet This does a rudimentary verification to make sure the packet at least contains the signature data and it returns the reference to the signature.
should_track_transactionDeprecated
Check if a transaction given its signature matches the randomly selected mask. The signature should be from the reference of Signature
signature_if_should_track_packetDeprecated
Check if a transaction packet’s signature matches the mask. This does a rudimentary verification to make sure the packet at least contains the signature data and it returns the reference to the signature.