👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Functions
- get_
signature_ from_ packet Deprecated - Get the signature of the transaction packet This does a rudimentary verification to make sure the packet at least contains the signature data and it returns the reference to the signature.
- should_
track_ transaction Deprecated - Check if a transaction given its signature matches the randomly selected mask. The signature should be from the reference of Signature
- signature_
if_ should_ track_ packet Deprecated - Check if a transaction packet’s signature matches the mask. This does a rudimentary verification to make sure the packet at least contains the signature data and it returns the reference to the signature.